@@ -9,5 +9,5 @@ test_that("corrPlot", {
   data(exampleData)
   responses <- c("Area","Area.SV","Area.TV", "Image.Biomass", "Max.Height","Centre.Mass",
                  "Density", "Compactness.TV", "Compactness.SV")
- testthat::expect_silent(corrPlot(responses, longi.dat, pairs.sets=list(c(1:4),c(5:7))))
+ testthat::expect_warning(corrPlot(responses, longi.dat, pairs.sets=list(c(1:4),c(5:7))))
 })
\ No newline at end of file
