@@ -317,12 +317,12 @@ test_that("Rice2015_imageData", {
   big.SIIT <- with(tmp, tmp[tmp[SIIT] > 1.15, c("Snapshot.ID.Tag.C","Genotype.ID",
                                                 paste(response,"C",sep="."), 
                                                 paste(response,"S",sep="."), SIIT)])
-  big.SIIT <- big.SIIT[order(big.SIIT[SIIT]),]
+  big.SIIT <- big.SIIT[order(big.SIIT[[SIIT]]),]
   testthat::expect_equal(nrow(big.SIIT), 0)
   testthat::expect_equal(ncol(big.SIIT), 5)
   print(big.SIIT)
   plt <- ggplot(tmp, aes_string(SIIT)) +
-    geom_histogram(aes(y = ..density..), binwidth=0.05) +
+    geom_histogram(aes(y = after_stat(density)), binwidth=0.05) +
     geom_vline(xintercept=1.15, linetype="longdash", size=1) +
     theme_bw() + facet_grid(Smarthouse ~.)
   print(plt)
